@@ -1,4 +1,4 @@
-pql <- function(mod.mcml,family.mcml,cache){
+pql <- function(mod.mcml,family.mcml, wts,cache){
    	if (! missing(cache))
        	    stopifnot(is.environment(cache))
 	eek <- getEk(mod.mcml$z)
@@ -19,14 +19,14 @@ pql <- function(mod.mcml,family.mcml,cache){
 	
 	outer.optim<-suppressWarnings(optim(par=sigma, fn=fn.outer,  beta=beta, 
 		s=s, Y=mod.mcml$y , X = mod.mcml$x ,Z=Z, eek=eek, family.mcml=family.mcml, 
-		cache=cache, ntrials = mod.mcml$ntrials))
+		cache=cache, ntrials = mod.mcml$ntrials, wts=wts))
 
 	list(sigma = outer.optim$par)
 
 }
 
 
-fn.outer <- function(par, beta, s, Y, X, Z, eek, family.mcml, cache, ntrials){
+fn.outer <- function(par, beta, s, Y, X, Z, eek, family.mcml, cache, ntrials, wts){
 	sigma <- par
 	Aks <- Map("*",eek,sigma)
 	A <- addVecs(Aks) #at this point still a vector
@@ -52,7 +52,7 @@ fn.outer <- function(par, beta, s, Y, X, Z, eek, family.mcml, cache, ntrials){
 	nbeta<-length(beta)
 	#run trust
 	inner.optim<-trust(fn.inner.trust,parinit=c(beta,s), rinit=5, rmax=10000, minimize=F, 
-		Y=Y, X=X, Z=Z, A=A, nbeta=nbeta, family.mcml=family.mcml, cache=cache, ntrials = ntrials)
+		Y=Y, X=X, Z=Z, A=A, nbeta=nbeta, family.mcml=family.mcml, cache=cache, ntrials = ntrials, wts=wts)
 	
 	#get beta and s
 	beta.twid <- cache$beta.twid
@@ -66,15 +66,15 @@ fn.outer <- function(par, beta, s, Y, X, Z, eek, family.mcml, cache, ntrials){
 
 	if(family.mcml$family.glmm == "bernoulli.glmm"){
 		piece1 <- .C(C_elc, as.double(Y), as.double(X), as.integer(nrow(X)), 
-			as.integer(ncol(X)), as.double(eta.twid), as.integer(1), as.integer(ntrials), 
+			as.integer(ncol(X)), as.double(eta.twid), as.integer(1), as.integer(ntrials), wts = as.double(wts),
 			value=double(1), gradient=double(ncol(X)), hessian=double((ncol(X)^2)))$value}
 	if(family.mcml$family.glmm=="poisson.glmm"){
 		piece1 <- .C(C_elc, as.double(Y), as.double(X), as.integer(nrow(X)), 
-			as.integer(ncol(X)), as.double(eta.twid), as.integer(2), as.integer(ntrials), 
+			as.integer(ncol(X)), as.double(eta.twid), as.integer(2), as.integer(ntrials), wts = as.double(wts),
 			value=double(1), gradient=double(ncol(X)), hessian=double((ncol(X)^2)))$value}
 	if(family.mcml$family.glmm=="binomial.glmm"){
 		piece1 <- .C(C_elc, as.double(Y), as.double(X), as.integer(nrow(X)), 
-			as.integer(ncol(X)), as.double(eta.twid), as.integer(3), as.integer(ntrials), 
+			as.integer(ncol(X)), as.double(eta.twid), as.integer(3), as.integer(ntrials), wts = as.double(wts),
 			value=double(1), gradient=double(ncol(X)), hessian=double((ncol(X)^2)))$value}
 	
 	#calculate W = c''(eta.twid)
@@ -101,7 +101,7 @@ fn.outer <- function(par, beta, s, Y, X, Z, eek, family.mcml, cache, ntrials){
 }
 
 fn.inner.trust <-
-function(mypar,Y,X,Z,A,family.mcml,nbeta,cache, ntrials )
+function(mypar,Y,X,Z,A,family.mcml,nbeta,cache, ntrials, wts)
 {
 	beta <- mypar[1:nbeta]
 	s <- mypar[-(1:nbeta)]
@@ -116,15 +116,15 @@ function(mypar,Y,X,Z,A,family.mcml,nbeta,cache, ntrials )
 	#value<- ellikelihood(Y,X,eta,family.mcml)$value-.5*s%*%s
 	if(family.mcml$family.glmm=="bernoulli.glmm"){
 		value<-.C(C_elc, as.double(Y), as.double(X), as.integer(nrow(X)), 
-			as.integer(ncol(X)), as.double(eta),as.integer(1),as.integer(ntrials), 
+			as.integer(ncol(X)), as.double(eta),as.integer(1),as.integer(ntrials), wts = as.double(wts),
 			value=double(1), gradient=double(ncol(X)), hessian=double((ncol(X)^2)))$value-.5*s%*%s}
 	if(family.mcml$family.glmm=="poisson.glmm"){
 		value<-.C(C_elc, as.double(Y), as.double(X), as.integer(nrow(X)), 
-			as.integer(ncol(X)), as.double(eta), as.integer(2), as.integer(ntrials), 
+			as.integer(ncol(X)), as.double(eta), as.integer(2), as.integer(ntrials), wts = as.double(wts),
 			value=double(1), gradient=double(ncol(X)), hessian=double((ncol(X)^2)))$value-.5*s%*%s}
 	if(family.mcml$family.glmm=="binomial.glmm"){
 		value <- .C(C_elc, as.double(Y), as.double(X), as.integer(nrow(X)), 
-			as.integer(ncol(X)), as.double(eta), as.integer(3), as.integer(ntrials), 
+			as.integer(ncol(X)), as.double(eta), as.integer(3), as.integer(ntrials), wts = as.double(wts),
 			value=double(1), gradient=double(ncol(X)), hessian=double((ncol(X)^2)))$value-.5*s%*%s}
 	
 	#gradient calculation
