@@ -9,13 +9,12 @@ void distRandGenC(double *SigmaInv, double *logdet, int *nrow, double *uvec, dou
 	double *blah=Calloc(*nrow,double);
 	/* calculates blah=SigmaInv%*%umu  */
 	matvecmult(SigmaInv,umu,nrow,nrow,blah);
-	double *blah2=Calloc(1,double);
+	double blah2;
 	int thing1=1,*ione=&thing1;
 	/*calculates blah2=t(umu)%*%Sigma.inv %*% umu */
-	matTvecmult(umu,blah,nrow,ione,blah2);
+	matTvecmult(umu,blah,nrow,ione,&blah2);
 
 	Free(blah);
 	Free(umu);
-	*distRandGenVal=.5*((-*nrow)*log(2*PI)+ (*logdet)-(*blah2));
-	Free(blah2);
+	*distRandGenVal=.5*((-*nrow)*log(2*PI)+ (*logdet)-blah2);
 }
