@@ -25,7 +25,7 @@ addVecs<-glmm:::addVecs
 genRand<-glmm:::genRand
 
 vars$family.glmm<-sal$family.glmm
-vars$ntrials<-1
+vars$ntrials<- rep(1, length(sal$y))
 beta.pql <- debug$beta.pql
 
 simulate <- function(vars, Dstarnotsparse, m2, m3, beta.pql, D.star.inv){
@@ -77,7 +77,7 @@ beta<-rep(0,4)
 nu<-rep(2,2)
 par<-c(beta,nu)
 del<-rep(10^-6,6)
-
+vars$wts <- rep(1, nrow(salamander))
 objfun<-glmm:::objfun
 
 cache<-new.env(parent = emptyenv())
